
#loading libraries
library(rgdal)
library(adehabitatLT)
library(xlsx)

#reading xlsx table
coto <- read.xlsx('D:/Google Drive/Jaguar habitat use in the Vrzea Floodplain Forest/coto_659807A_20130719.xlsx',1)

#subseting data to exclude NAs from 'data' column to avoid errors in ltraj object
coto_nonas <- subset(coto, coto$data != 'NA')

#re-subseting to exclude rows with no coordinates
coto_nonas2 <- subset(coto, coto$GPS_Latitude != 'NA')

#creating and appending a column with animal name
coto_nonas2$id <- 'Coto'

#creating a dataframe with dates and times
data <- as.character(coto_nonas2$data)

#inspecting....
head(data)

#converting dates/times as POSIXct and inspecting
data <- as.POSIXct(strptime(as.character(coto_nonas2$data),'%Y-%m-%d %H:%M:%S'))
head(data)

#cheking for duplicate dates, which will return an error in ltraj object
dupes <- data[which(duplicated(data))]
dupes

#creating a ltraj object to store jaguar movements
coto_moves <- as.ltraj(xy=coto_nonas2[c('GPS_UTM_Easting','GPS_UTM_Northing')],date=data, id=coto_nonas2$id, typeII=TRUE)

#take a look at the first rows of the movement variables
head(coto_moves[[1]])

#Ploting Distance of each relocation X Date
plotltr(coto_moves)

#Placing the missing values in the trajectory
# The relocations have been collected daily, but there are many days during which
# this relocation was not possible (storm, lack of field workers, etc.). 
# We need to add missing values to define a regular trajectory.
# We have to define a reference date that will be used to check that each date in 
# the object of class ltraj is separated from this reference by an integer multiple
# of the theoretical dt (here, one day), and place the missing values at the times 
# when relocations should theoretically have been collected.

refdata <- strptime('2013-02-13 00:00:00', '%Y-%m-%d %H:%M:%S')

# function setNA to place the missing values with theoretical collects every 6 hours
coto_moves2 <- setNA(coto_moves, refdata, 6, units = 'hour')

# Even when filling the gaps with NAs, the trajectory is still not regular.
# The function sett0 can be used to 'round' the timing of the coordinates.
coto_moves3 <- sett0(coto_moves2, refdata, 6, units = "hour")

# test whether the missing values occur at random in the monitoring
summaryNAltraj(coto_moves3)
runsNAltraj(coto_moves3)

#In the case of Cot, the missing values are not randomly distributed, it's clustered.
# So, have a look at distribution of this values
plotNAltraj(coto_moves3)

# Because of the high number of relocations in this trajectory, this graph is
# not very clear. So a better way to study the distribution of the missing values
# is to work directly on the vector indicating whether the relocations are missing
# or not using classical time series methods. Lets create it only to take a look (these
# the analysis are not for now)
missval <- as.numeric(is.na(coto_moves3[[1]]$x))
missval

# interactively show the relocations, only for fun...
win.graph(7,7,12)

# The independence test of Wald and Wolfowitz (1944) can be used to test the sequential 
# autocorrelation  for the three linear parameters dx, dy and dist (increments in x and y 
# directions and distance) for each burst in an object of class ltraj. 
# Trouble: There are no autocorrelation!!! See later (rediscretization in time or space?)
wawotest(coto_moves3)




